@@ -19,6 +19,7 @@ from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
+from calculate.lib.variables.system import RootType
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
@@ -61,6 +62,11 @@ class ClBuilderImageAction(Action):
          'method': 'Builder.iso_migrate(cl_builder_flash_path)',
          'condition': lambda Get: Get('cl_builder_rescratch_set') == 'on'
          },
+        {'name': 'remount_data',
+         'method': 'Builder.remount_rw(cl_isoscan_base_path)',
+         'condition': lambda Get: (
+             Get('os_root_type_ext') in RootType.IsoScanGrub)
+         },
         {'name': 'prepare_action',
          'method': 'Builder.set_builder_action("prepare")',
          },
@@ -165,21 +171,32 @@ class ClBuilderImageAction(Action):
               'method': 'Builder.mount_target(cl_builder_target)',
               'condition': lambda Get: Get('cl_builder_build')
               },
-             {'name': 'image_menu',
+             {'name': 'flash_menu',
               'method': 'Builder.set_builder_action("%s")' % Actions.ImageMenu,
               'condition': lambda Get: Get('cl_builder_rescratch_set') == 'on'
               },
-             {'name': 'image_menu:remove_flash_tmp',
+             {'name': 'flash_menu:remove_flash_tmp',
               'method': 'Builder.remove_flash_tmp()'
               },
-             {'name': 'image_menu:sync_vmlinuz',
+             {'name': 'flash_menu:sync_vmlinuz',
               'message': __("Extracting kernels from ISO images"),
               'method': 'Builder.sync_vmlinuz(cl_builder_flash_path)'
               },
-             {'name': 'image_menu:update_menu',
+             {'name': 'flash_menu:update_menu',
               'message': __("Recreating ISO image menu"),
               'method': 'Builder.update_menu(cl_builder_flash_path)',
               },
+             {'name': 'grub_menu',
+              'method': 'Builder.set_builder_action("%s")' % Actions.ImageMenu,
+              'condition': lambda Get: (
+                  Get('cl_builder_grub_refresh_set') == 'on')
+              },
+             {'name': 'grub_menu:update_grub_menu',
+              'message': __("Creating the ISO images menu"),
+              'method': 'Builder.create_iso_grub_cfg(cl_builder_livemenu_path)',
+              'condition': lambda Get: (
+                  Get('builder.cl_builder_livemenu_path') != "")
+              },
          ]
          },
         {'name': 'failed',
